##############################################################################
#
# Copyright (c) 2007 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""zope.broken interfaces.

$Id: interfaces.py 72735 2007-02-21 05:02:33Z baijum $
"""

__docformat__ = "reStructuredText"

import zope.interface

try:
    from ZODB.interfaces import IBroken
except ImportError:
    class IBroken(zope.interface.Interface):
        """Marker interface for broken objects
        """
